LogLevel

Struct LogLevel 

#[repr(transparent)]
pub struct LogLevel(pub c_uint);
Enumerates log levels.

You are advised to select log levels based on their respective usage scenarios:

  • DEBUG: used for debugging and disabled from commercial releases
  • INFO: used for logging important system running status and steps in key processes
  • WARN: used for logging unexpected exceptions that have little impact on user experience and can automatically recover. Logs at this level are generally output when such exceptions are detected and captured.
  • ERROR: used for logging malfunction that affects user experience and cannot automatically recover
  • FATAL: used for logging major exceptions that have severely affected user experience and should not occur.

Available since API-level: 8

Tuple Fields

0: c_uint

Implementations

Source

impl LogLevel

pub const LOG_DEBUG: LogLevel

Debug level to be used by [OH_LOG_DEBUG]

pub const LOG_INFO: LogLevel

Informational level to be used by [OH_LOG_INFO]

pub const LOG_WARN: LogLevel

Warning level to be used by [OH_LOG_WARN]

pub const LOG_ERROR: LogLevel

Error level to be used by [OH_LOG_ERROR]

pub const LOG_FATAL: LogLevel

Fatal level to be used by [OH_LOG_FATAL]