pub type LogCallback = Option<unsafe extern "C" fn(type_: LogType, level: LogLevel, domain: c_uint, tag: *const c_char, msg: *const c_char)>;Available on crate feature
api-11 only.Expand description
Defines the function pointer type for the user-defined log processing function.
Arguments
-
type- Indicates the log type. The type for third-party applications is defined by [LOG_APP]. -
level- Indicates the log level, which can be LOG_DEBUG, LOG_INFO, LOG_WARN, LOG_ERROR, and LOG_FATAL. -
domain- Indicates the service domain of logs. Its value is a hexadecimal integer ranging from 0x0 to 0xFFFF. -
tag- Indicates the log tag, which is a string used to identify the class, file, or service behavior. -
msg- Indicates the log message itself, which is a formatted log string.
Available since API-level: 11
Aliased Type
pub enum LogCallback {
None,
Some(unsafe extern "C" fn(LogType, LogLevel, u32, *const u8, *const u8)),
}